@@ -26,7 +26,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-help.h>
 #include <panel-applet-gconf.h>
 #include <X11/XKBlib.h>
 #define XK_MISCELLANY
@@ -152,10 +151,10 @@ help_cb (BonoboUIComponent   *uic,
 {
 	GError *error = NULL;
 
-	gnome_help_display_on_screen (
-		"accessx-status.xml", NULL,
-		gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
-		&error);
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
+			"ghelp:accessx-status",
+			gtk_get_current_event_time (),
+			&error);
 
 	if (error) { 
 		GtkWidget *parent =
@@ -412,7 +411,7 @@ accessx_status_applet_get_glyph_pixbuf (AccessxStatusApplet *sapplet,
 	g_object_unref (layout);
 	glyph_pixbuf = gdk_pixbuf_get_from_drawable (NULL, pixmap, 
 						     cmap, 0, 0, 0, 0, w, h);
-	gdk_pixmap_unref (pixmap);
+	g_object_unref (pixmap);
 	alpha_pixbuf = gdk_pixbuf_add_alpha (glyph_pixbuf, TRUE, bg->red >> 8, bg->green >> 8, bg->blue >> 8);
 	g_object_unref (G_OBJECT (glyph_pixbuf));
 	g_object_unref (G_OBJECT (cmap));
@@ -892,17 +891,13 @@ accessx_applet_add_stock_icons (AccessxStatusApplet *sapplet, GtkWidget *widget)
 		gchar *set_name = stock_icons[i].stock_id;
                 icon_set = gtk_icon_set_new ();
 		do {
-			char *filename, *tmp;
+			char *filename;
 			GtkIconSource *source = gtk_icon_source_new ();
-			tmp = g_strdup_printf (GNOME_PIXMAPSDIR
-					"/accessx-status-applet/%s",
-					stock_icons[i].name);
-			filename = gnome_program_locate_file (NULL,
-					GNOME_FILE_DOMAIN_PIXMAP, 
-					  tmp, 
-					  FALSE, NULL);
-			g_free (tmp);
-			if (!filename) {
+			filename = g_build_filename (ACCESSX_PIXMAPS_DIR,
+						     stock_icons[i].name,
+						     NULL);
+			if (g_file_test (filename, G_FILE_TEST_EXISTS | 
+					 G_FILE_TEST_IS_REGULAR)) {
 				GtkIconSet *default_set = 
 					gtk_icon_factory_lookup_default (GTK_STOCK_MISSING_IMAGE);
 				gtk_icon_source_set_pixbuf (source,
