@@ -30,7 +30,6 @@
 
 #include <gdk/gdkscreen.h>
 #include <gdk/gdkx.h>
-#include <libgnomeui/gnome-help.h>
 
 #define GROUPS_SUBMENU_PATH "/popups/popup/groups"
 #define PLUGINS_CAPPLET_EXECUTABLE "gkbd-indicator-plugins-capplet"
@@ -151,14 +150,17 @@ GSwitchItAppletSetBackground (PanelApplet * applet, GtkWidget * w)
 
 	/* go down */
 	if (GTK_IS_CONTAINER (w)) {
-		GList *child =
+                GList *child;
+		GList *children =
 		    gtk_container_get_children (GTK_CONTAINER (w));
+		child = children;
 		while (child != NULL) {
 			GSwitchItAppletSetBackground (applet,
 						      GTK_WIDGET (child->
 								  data));
 			child = child->next;
 		}
+		g_list_free (children);
 	}
 }
 
@@ -212,9 +214,10 @@ GSwitchItPreviewResponse (GtkWidget * dialog, gint resp)
 
 	switch (resp) {
 	case GTK_RESPONSE_HELP:
-		gnome_help_display_on_screen ("gswitchit", "layout-view",
-					      gtk_widget_get_screen
-					      (dialog), NULL);
+		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
+			"ghelp:gswitchit?layout-view",
+			gtk_get_current_event_time (),
+			NULL);
 		return;
 	case GTK_RESPONSE_CLOSE:
 		gtk_window_get_position (GTK_WINDOW (dialog), &rect.x,
@@ -444,9 +447,10 @@ void
 GSwitchItAppletCmdHelp (BonoboUIComponent
 			* uic, GSwitchItApplet * sia, const gchar * verb)
 {
-	gnome_help_display_on_screen ("gswitchit", NULL,
-				      gtk_widget_get_screen (sia->applet),
-				      NULL);
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (sia->applet)),
+		"ghelp:gswitchit-view",
+		gtk_get_current_event_time (),
+		NULL);
 } void
 GSwitchItAppletCmdAbout (BonoboUIComponent *
 			 uic, GSwitchItApplet * sia, const gchar * verb)
@@ -529,6 +533,7 @@ GSwitchItAppletSetupGroupsSubmenu (GSwitchItApplet * sia)
 		bonobo_ui_component_add_verb (popup, verb, (BonoboUIVerbFn)
 					      GSwitchItAppletCmdSetGroup,
 					      sia);
+                bonobo_ui_node_unref (node);
 		xkl_debug (160,
 			   "Registered group menu item \'%s\' as \'%s\'\n",
 			   verb, *currentName);
