@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c 11193 2009-01-14 07:56:46Z diegoe $ */
+/* $Id: gweather-applet.c 11220 2009-01-25 23:43:11Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -332,7 +332,7 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     g_signal_connect (G_OBJECT(gw_applet->applet), "destroy", 
                        G_CALLBACK (applet_destroy), gw_applet);
     g_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
-                       GTK_SIGNAL_FUNC(clicked_cb), gw_applet);
+                       G_CALLBACK(clicked_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "key_press_event",           
 			G_CALLBACK(key_press_cb), gw_applet);
                      
