@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c 10529 2007-11-22 07:59:29Z callum $ */
+/* $Id: gweather-dialog.c 11193 2009-01-14 07:56:46Z diegoe $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -19,7 +19,8 @@
 #include <assert.h>
 
 #include <gconf/gconf-client.h>
-#include <gnome.h>
+
+#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
 
 #include "gweather.h"
 #include "gweather-applet.h"
@@ -135,7 +136,10 @@ static void
 link_cb (GtkButton *button,
          gpointer data)
 {
-    gnome_url_show("http://www.weather.com/", NULL);
+    gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (button)),
+		    "http://www.weather.com/",
+		    gtk_get_current_event_time (),
+		    NULL);
 }
 
 static gchar*
